@@ -94,7 +94,8 @@ def drawWinglets(data, colorArray = ['red', 'blue', 'pink', 'orange', 'purple',
         dataDict = listTransDict(data)
     else:
         dataDict = data
-    if len(colorArray) < len(dataDict.keys()) or len(colorArray) < getMaxKey(dataDict):
+    # if len(colorArray) < len(dataDict.keys()) or len(colorArray) < getMaxKey(dataDict):
+    if len(colorArray) < len(dataDict.keys()):
         raise ColorNotEnoughError('colorArray length is not enough')
     operationInstance.mapColor(colorArray, dataDict)
     operationInstance.drawWinglets(dataDict)
@@ -107,7 +108,8 @@ def drawCommonFate(data, colorArray = ['red', 'blue', 'pink', 'orange', 'purple'
         dataDict = listTransDict(data)
     else:
         dataDict = data
-    if len(colorArray) < len(dataDict.keys()) or len(colorArray) < getMaxKey(dataDict):
+    # if len(colorArray) < len(dataDict.keys()) or len(colorArray) < getMaxKey(dataDict):
+    if len(colorArray) < len(dataDict.keys()):
         raise ColorNotEnoughError('colorArray length is not enough')
     operationInstance.mapColor(colorArray, dataDict)
     operationInstance.drawCommonFateEffect(dataDict)
@@ -120,7 +122,8 @@ def drawProximity(data, colorArray = ['red', 'blue', 'pink', 'orange', 'purple',
         dataDict = listTransDict(data)
     else:
         dataDict = data
-    if len(colorArray) < len(dataDict.keys()) or len(colorArray) < getMaxKey(dataDict):
+    # if len(colorArray) < len(dataDict.keys()) or len(colorArray) < getMaxKey(dataDict):
+    if len(colorArray) < len(dataDict.keys()):
         raise ColorNotEnoughError('colorArray length is not enough')
     operationInstance.mapColor(colorArray, dataDict)
     operationInstance.drawProximityEffect(dataDict)
@@ -141,8 +144,9 @@ for curKey in dataDict['dots'].keys():
     dataArray.append(curKeyArr)
 # print('dataArray', dataArray)
 # drawCirlce(dataArray, ['#d7191c', '#fdae61', '#ffffbf', '#abdda4', '#2b83ba'], False)
-drawWinglets(dataArray, ['#d7191c', '#fdae61', '#ffffbf', '#abdda4', '#2b83ba'])
+# drawWinglets(dataArray, ['#d7191c', '#fdae61', '#ffffbf', '#abdda4'])
 # drawWinglets(dataArray, ['#d7191c', '#fdae61', '#ffffbf', '#abdda4', '#2b83ba'])
 # drawCommonFate(dataArray, ['#d7191c', '#fdae61', '#ffffbf', '#abdda4', '#2b83ba'])
-# drawProximity(dataArray, ['#d7191c', '#fdae61', '#ffffbf', '#abdda4', '#2b83ba'])
+# drawProximity(dataArray, ['#d7191c', '#fdae61', '#ffffbf', '#abdda4'])
+drawProximity(dataDict['dots'], ['#d7191c', '#fdae61', '#ffffbf', '#abdda4'])
 # draw(dataDict['dots'], ['#d7191c', '#fdae61', '#ffffbf', '#abdda4', '#2b83ba'])
